@@ -2,7 +2,10 @@ use {
     super::*,
     crate::{
         app::Mode,
-        cli::{Args, TriBool},
+        cli::{
+            Args,
+            TriBool,
+        },
         conf::*,
         content_search,
         display::LayoutInstructions,
@@ -10,8 +13,8 @@ use {
         file_sum,
         icon::*,
         kitty::TransmissionMedium,
-        pattern::SearchModeMap,
         path::SpecialPaths,
+        pattern::SearchModeMap,
         preview::PreviewTransformers,
         skin::ExtColorMap,
         syntactic::SyntaxTheme,
@@ -20,17 +23,22 @@ use {
     },
     crokey::crossterm::tty::IsTty,
     std::{
-        convert::{TryFrom, TryInto},
+        convert::{
+            TryFrom,
+            TryInto,
+        },
         io,
         num::NonZeroUsize,
-        path::{Path, PathBuf},
+        path::{
+            Path,
+            PathBuf,
+        },
     },
 };
 
 /// The container that can be passed around to provide the configuration things
 /// for the whole life of the App
 pub struct AppContext {
-
     /// Whether the application is running in a normal TTY context
     pub is_tty: bool,
 
@@ -114,6 +122,9 @@ pub struct AppContext {
     /// (if none, the title isn't modified)
     pub terminal_title_pattern: Option<ExecPattern>,
 
+    /// whether to reset the terminal's title on exit
+    pub reset_terminal_title_on_exit: bool,
+
     /// whether to sync broot's work dir with the current panel's root
     pub update_work_dir: bool,
 
@@ -159,8 +170,7 @@ impl AppContext {
         } else {
             are_true_colors_available()
         };
-        let icons = config.icon_theme.as_ref()
-            .and_then(|itn| icon_plugin(itn));
+        let icons = config.icon_theme.as_ref().and_then(|itn| icon_plugin(itn));
         let mut special_paths: SpecialPaths = (&config.special_paths).try_into()?;
         special_paths.add_defaults();
         let search_modes = config
@@ -169,24 +179,23 @@ impl AppContext {
             .map(TryInto::try_into)
             .transpose()?
             .unwrap_or_default();
-        let ext_colors = ExtColorMap::try_from(&config.ext_colors)
-            .map_err(ConfError::from)?;
-        let file_sum_threads_count = config.file_sum_threads_count
+        let ext_colors = ExtColorMap::try_from(&config.ext_colors).map_err(ConfError::from)?;
+        let file_sum_threads_count = config
+            .file_sum_threads_count
             .unwrap_or(file_sum::DEFAULT_THREAD_COUNT);
         if !(1..=50).contains(&file_sum_threads_count) {
-            return Err(ConfError::InvalidThreadsCount{ count: file_sum_threads_count }.into());
+            return Err(ConfError::InvalidThreadsCount {
+                count: file_sum_threads_count,
+            }
+            .into());
         }
-        let max_panels_count = config.max_panels_count
-            .unwrap_or(2)
-            .clamp(2, 100);
+        let max_panels_count = config.max_panels_count.unwrap_or(2).clamp(2, 100);
         let capture_mouse = match (config.capture_mouse, config.disable_mouse_capture) {
             (Some(b), _) => b, // the new "capture_mouse" argument takes precedence
             (_, Some(b)) => !b,
             _ => true,
         };
-        let max_staged_count = config.max_staged_count
-            .unwrap_or(10_000)
-            .clamp(10, 100_000);
+        let max_staged_count = config.max_staged_count.unwrap_or(10_000).clamp(10, 100_000);
         let (initial_root, initial_file) = initial_root_file(&launch_args)?;
 
         // tree options are built from the default_flags
@@ -202,16 +211,18 @@ impl AppContext {
             initial_tree_options.show_selection_mark = true;
         }
 
-        let content_search_max_file_size = config.content_search_max_file_size
+        let content_search_max_file_size = config
+            .content_search_max_file_size
             .map(|u64value| usize::try_from(u64value).unwrap_or(usize::MAX))
             .unwrap_or(content_search::DEFAULT_MAX_FILE_SIZE);
 
         let terminal_title_pattern = config.terminal_title.clone();
+        let reset_terminal_title_on_exit = config.reset_terminal_title_on_exit.unwrap_or(false);
         let preview_transformers = PreviewTransformers::new(&config.preview_transformers)?;
         let layout_instructions = config.layout_instructions.clone().unwrap_or_default();
-        let kept_kitty_temp_files = config.kept_kitty_temp_files.unwrap_or(
-            std::num::NonZeroUsize::new(500).unwrap(),
-        );
+        let kept_kitty_temp_files = config
+            .kept_kitty_temp_files
+            .unwrap_or(std::num::NonZeroUsize::new(500).unwrap());
 
         Ok(Self {
             is_tty,
@@ -239,10 +250,10 @@ impl AppContext {
             max_staged_count,
             content_search_max_file_size,
             terminal_title_pattern,
+            reset_terminal_title_on_exit,
             update_work_dir: config.update_work_dir.unwrap_or(true),
             keyboard_enhanced: false,
-            kitty_graphics_transmission: config.kitty_graphics_transmission
-                .unwrap_or_default(),
+            kitty_graphics_transmission: config.kitty_graphics_transmission.unwrap_or_default(),
             kept_kitty_temp_files,
             lines_after_match_in_preview: config.lines_after_match_in_preview.unwrap_or(0),
             lines_before_match_in_preview: config.lines_before_match_in_preview.unwrap_or(0),
@@ -250,12 +261,17 @@ impl AppContext {
             layout_instructions,
         })
     }
-    /// Return the --cmd argument, coming from the launch arguments (prefered)
+    /// Return the --cmd argument, coming from the launch arguments (preferred)
     /// or from the default_flags parameter of a config file
     pub fn cmd(&self) -> Option<&str> {
-        self.launch_args.cmd.as_ref().or(
-            self.config_default_args.as_ref().and_then(|args| args.cmd.as_ref())
-        ).map(String::as_str)
+        self.launch_args
+            .cmd
+            .as_ref()
+            .or(self
+                .config_default_args
+                .as_ref()
+                .and_then(|args| args.cmd.as_ref()))
+            .map(String::as_str)
     }
     pub fn initial_mode(&self) -> Mode {
         if self.modal {
@@ -310,7 +326,8 @@ fn initial_root_file(cli_args: &Args) -> Result<(PathBuf, Option<PathBuf>), Prog
     if !root.exists() {
         return Err(TreeBuildError::FileNotFound {
             path: format!("{:?}", &root),
-        }.into());
+        }
+        .into());
     }
     if !root.is_dir() {
         // we try to open the parent directory if the passed file isn't one
@@ -322,7 +339,8 @@ fn initial_root_file(cli_args: &Args) -> Result<(PathBuf, Option<PathBuf>), Prog
             // this is a weird filesystem, let's give up
             return Err(TreeBuildError::NotADirectory {
                 path: format!("{:?}", &root),
-            }.into());
+            }
+            .into());
         }
     }
     Ok((root, file))
@@ -341,5 +359,3 @@ fn canonicalize_root(root: &Path) -> io::Result<PathBuf> {
         root.to_path_buf()
     })
 }
-
-
