@@ -89,7 +89,7 @@ impl FromStr for Col {
             "staged" => Ok(Self::Staged),
             "n" | "name" => Ok(Self::Name),
             _ => Err(ConfError::InvalidCols {
-                details: format!("column not recognized : {}", s),
+                details: format!("column not recognized : {s}"),
             }),
         }
     }
@@ -97,7 +97,10 @@ impl FromStr for Col {
 
 impl Col {
     /// return the index of the column among the complete Cols ordered list
-    pub fn index_in(self, cols: &Cols) -> Option<usize> {
+    pub fn index_in(
+        self,
+        cols: &Cols,
+    ) -> Option<usize> {
         for (idx, col) in cols.iter().enumerate() {
             if *col == self {
                 return Some(idx);
@@ -139,7 +142,6 @@ impl Col {
             Col::Staged => false,
             Col::Name => true,
         }
-
     }
 }
 
@@ -161,7 +163,7 @@ pub fn parse_cols(arr: &Vec<String>) -> Result<Cols, ConfError> {
     for (idx, s) in arr.iter().enumerate() {
         if idx >= COLS_COUNT {
             return Err(ConfError::InvalidCols {
-                details: format!("too long: {:?}", arr),
+                details: format!("too long: {arr:?}"),
             });
         }
         // we swap the cols, to ensure both keeps being present
@@ -179,4 +181,3 @@ pub fn parse_cols(arr: &Vec<String>) -> Result<Cols, ConfError> {
 pub fn parse_cols_single_str(s: &str) -> Result<Cols, ConfError> {
     parse_cols(&s.chars().map(String::from).collect())
 }
-
