@@ -1,8 +1,6 @@
 use {
     cli_log::*,
-    std::{
-        env,
-    },
+    std::env,
 };
 
 /// Determine whether Kitty's graphics protocol is supported
@@ -49,6 +47,9 @@ pub fn is_kitty_graphics_protocol_supported() -> bool {
             } else {
                 warn!("$TERM_PROGRAM_VERSION unexpectedly missing");
             }
+        } else if term_program == "ghostty" {
+            debug!("Ghostty implements Kitty Graphics protocol");
+            return true;
         }
     }
 
@@ -62,7 +63,7 @@ pub fn is_kitty_graphics_protocol_supported() -> bool {
     {
         let start = std::time::Instant::now();
         const TIMEOUT_MS: u64 = 200;
-        let response = xterm_query::query(
+        let response = xterm_query::query_osc(
             "\x1b_Gi=31,s=1,v=1,a=q,t=d,f=24;AAAA\x1b\\\x1b[c",
             TIMEOUT_MS,
         );
@@ -71,9 +72,7 @@ pub fn is_kitty_graphics_protocol_supported() -> bool {
                 debug!("xterm querying failed: {}", e);
                 false
             }
-            Ok(response) => {
-                response.starts_with("\x1b_Gi=31;OK\x1b")
-            }
+            Ok(response) => response == "_Gi=31;OK",
         };
         debug!("Xterm querying took {:?}", start.elapsed());
         debug!("kitty protocol support: {:?}", s);
@@ -81,4 +80,3 @@ pub fn is_kitty_graphics_protocol_supported() -> bool {
     }
     false
 }
-
