@@ -1,9 +1,7 @@
 mod detect_support;
 mod image_renderer;
 
-pub use {
-    image_renderer::*,
-};
+pub use image_renderer::*;
 
 use {
     crate::{
@@ -16,6 +14,7 @@ use {
     once_cell::sync::Lazy,
     std::{
         io::Write,
+        path::Path,
         sync::Mutex,
     },
     termimad::Area,
@@ -51,9 +50,7 @@ struct RenderedImage {
 enum MaybeRenderer {
     Untested,
     Disabled,
-    Enabled {
-        renderer: KittyImageRenderer,
-    },
+    Enabled { renderer: KittyImageRenderer },
 }
 
 impl KittyManager {
@@ -65,6 +62,11 @@ impl KittyManager {
             _ => None,
         }
     }
+    pub fn delete_temp_files(&mut self) {
+        if let MaybeRenderer::Enabled { renderer } = &mut self.renderer {
+            renderer.delete_temp_files();
+        }
+    }
     pub fn renderer(
         &mut self,
         con: &AppContext,
@@ -77,9 +79,9 @@ impl KittyManager {
         }
         let options = KittyImageRendererOptions {
             transmission_medium: con.kitty_graphics_transmission,
+            kept_temp_files: con.kept_kitty_temp_files,
         };
-        // we're in the Untested branch
-        match KittyImageRenderer::new(&options) {
+        match KittyImageRenderer::new(options) {
             Some(renderer) => {
                 self.renderer = MaybeRenderer::Enabled { renderer };
                 self.renderer_if_tested()
@@ -101,10 +103,12 @@ impl KittyManager {
             }
         }
     }
+    #[allow(clippy::too_many_arguments)] // yes, I know
     pub fn try_print_image(
         &mut self,
         w: &mut W,
         src: &SourceImage,
+        src_path: &Path, // used to build a cache key
         area: &Area,
         bg: Color,
         drawing_count: usize,
@@ -112,7 +116,7 @@ impl KittyManager {
     ) -> Result<Option<KittyImageId>, ProgramError> {
         if let Some(renderer) = self.renderer(con) {
             let img = src.optimal()?;
-            let new_id = renderer.print(w, &img, area, bg)?;
+            let new_id = renderer.print(w, &img, src_path, area, bg)?;
             self.rendered_images.push(RenderedImage {
                 image_id: new_id,
                 drawing_count,
