@@ -11,13 +11,21 @@ use {
         skin::PanelSkin,
         syntactic::SyntacticView,
         task_sync::Dam,
+        tty::TtyView,
+    },
+    crokey::crossterm::{
+        QueueableCommand,
+        cursor,
     },
-    crokey::crossterm::{cursor, QueueableCommand},
     std::{
         io,
         path::Path,
     },
-    termimad::{Area, CropWriter, SPACE_FILLING},
+    termimad::{
+        Area,
+        CropWriter,
+        SPACE_FILLING,
+    },
 };
 
 #[allow(clippy::large_enum_variant)]
@@ -26,6 +34,7 @@ pub enum Preview {
     Image(ImageView),
     Syntactic(SyntacticView),
     Hex(HexView),
+    Tty(TtyView),
     ZeroLen(ZeroLenFileView),
     IoError(io::Error),
 }
@@ -43,6 +52,7 @@ impl Preview {
                 Some(PreviewMode::Hex) => Self::hex(path),
                 Some(PreviewMode::Image) => Self::image(path),
                 Some(PreviewMode::Text) => Self::unfiltered_text(path, con),
+                Some(PreviewMode::Tty) => Self::tty(path),
                 None => {
                     // automatic behavior: image, text, hex
                     ImageView::new(path)
@@ -63,28 +73,39 @@ impl Preview {
     ) -> Result<Self, ProgramError> {
         if path.is_file() {
             match mode {
-                PreviewMode::Hex => {
-                    Ok(HexView::new(path.to_path_buf()).map(Self::Hex)?)
-                }
-                PreviewMode::Image => {
-                    ImageView::new(path).map(Self::Image)
-                }
-                PreviewMode::Text => {
-                    Ok(
-                        SyntacticView::new(path, InputPattern::none(), &mut Dam::unlimited(), con, false)
-                            .transpose()
-                            .expect("syntactic view without pattern shouldn't be none")
-                            .map(Self::Syntactic)?,
-                    )
-                }
+                PreviewMode::Hex => Ok(HexView::new(path.to_path_buf()).map(Self::Hex)?),
+                PreviewMode::Image => ImageView::new(path).map(Self::Image),
+                PreviewMode::Tty => TtyView::new(path)
+                    .map(Self::Tty)
+                    .map_err(ProgramError::from),
+                PreviewMode::Text => Ok(SyntacticView::new(
+                    path,
+                    InputPattern::none(),
+                    &mut Dam::unlimited(),
+                    con,
+                    false,
+                )
+                .transpose()
+                .expect("syntactic view without pattern shouldn't be none")
+                .map(Self::Syntactic)?),
             }
         } else {
-            Ok(Self::dir(path, InputPattern::none(), &Dam::unlimited(), con))
+            Ok(Self::dir(
+                path,
+                InputPattern::none(),
+                &Dam::unlimited(),
+                con,
+            ))
         }
     }
 
     /// build a dir preview
-    pub fn dir(path: &Path, pattern: InputPattern, dam: &Dam, con: &AppContext) -> Self {
+    pub fn dir(
+        path: &Path,
+        pattern: InputPattern,
+        dam: &Dam,
+        con: &AppContext,
+    ) -> Self {
         match DirView::new(path.to_path_buf(), pattern, dam, con) {
             Ok(dv) => Self::Dir(dv),
             Err(e) => Self::IoError(e),
@@ -98,8 +119,16 @@ impl Preview {
             .ok()
             .map(Self::Image)
             .unwrap_or_else(|| Self::hex(path))
-
     }
+
+    /// build an tty view, unless there's an IO error
+    pub fn tty(path: &Path) -> Self {
+        match TtyView::new(path) {
+            Ok(tv) => Self::Tty(tv),
+            Err(e) => Self::IoError(e),
+        }
+    }
+
     /// build a text preview (maybe with syntaxic coloring) if possible,
     /// a hex (binary) view if content isnt't UTF8, a ZeroLen file if there's
     /// no length (it's probably a linux pseudofile) or a IOError when
@@ -108,7 +137,13 @@ impl Preview {
         path: &Path,
         con: &AppContext,
     ) -> Self {
-        match SyntacticView::new(path, InputPattern::none(), &mut Dam::unlimited(), con, false) {
+        match SyntacticView::new(
+            path,
+            InputPattern::none(),
+            &mut Dam::unlimited(),
+            con,
+            false,
+        ) {
             Ok(Some(sv)) => Self::Syntactic(sv),
             Err(ProgramError::ZeroLenFile | ProgramError::UnmappableFile) => {
                 debug!("zero len or unmappable file - check if system file");
@@ -153,7 +188,6 @@ impl Preview {
             match self {
                 Self::Syntactic(_) => {
                     match SyntacticView::new(path, pattern, dam, con, false) {
-
                         // normal finished loading
                         Ok(Some(sv)) => Some(Self::Syntactic(sv)),
 
@@ -190,6 +224,7 @@ impl Preview {
             Self::Syntactic(_) => Some(PreviewMode::Text),
             Self::ZeroLen(_) => Some(PreviewMode::Text),
             Self::Hex(_) => Some(PreviewMode::Hex),
+            Self::Tty(_) => Some(PreviewMode::Tty),
             Self::IoError(_) => None,
             Self::Dir(_) => None,
         }
@@ -209,6 +244,7 @@ impl Preview {
             Self::Dir(dv) => dv.try_scroll(cmd),
             Self::Syntactic(sv) => sv.try_scroll(cmd),
             Self::Hex(hv) => hv.try_scroll(cmd),
+            Self::Tty(v) => v.try_scroll(cmd),
             _ => false,
         }
     }
@@ -228,29 +264,42 @@ impl Preview {
             _ => None,
         }
     }
-    pub fn try_select_line_number(&mut self, number: usize) -> bool {
+    pub fn try_select_line_number(
+        &mut self,
+        number: usize,
+    ) -> bool {
         match self {
             Self::Syntactic(sv) => sv.try_select_line_number(number),
             _ => false,
         }
     }
     pub fn unselect(&mut self) {
-        // it's not possible to unselect in a dir_view
-        if let Self::Syntactic(sv) = self {
-            sv.unselect();
+        match self {
+            Self::Syntactic(sv) => sv.unselect(),
+            Self::Tty(tv) => tv.unselect(),
+            _ => {}
         }
     }
-    pub fn try_select_y(&mut self, y: u16) -> bool {
+    pub fn try_select_y(
+        &mut self,
+        y: u16,
+    ) -> bool {
         match self {
             Self::Dir(dv) => dv.try_select_y(y),
             Self::Syntactic(sv) => sv.try_select_y(y),
+            Self::Tty(v) => v.try_select_y(y),
             _ => false,
         }
     }
-    pub fn move_selection(&mut self, dy: i32, cycle: bool) {
+    pub fn move_selection(
+        &mut self,
+        dy: i32,
+        cycle: bool,
+    ) {
         match self {
             Self::Dir(dv) => dv.move_selection(dy, cycle),
             Self::Syntactic(sv) => sv.move_selection(dy, cycle),
+            Self::Tty(v) => v.move_selection(dy, cycle),
             Self::Hex(hv) => {
                 hv.try_scroll(ScrollCommand::Lines(dy));
             }
@@ -278,6 +327,7 @@ impl Preview {
             Self::Dir(dv) => dv.select_first(),
             Self::Syntactic(sv) => sv.select_first(),
             Self::Hex(hv) => hv.select_first(),
+            Self::Tty(v) => v.select_first(),
             _ => {}
         }
     }
@@ -285,6 +335,7 @@ impl Preview {
         match self {
             Self::Syntactic(sv) => sv.select_last(),
             Self::Hex(hv) => hv.select_last(),
+            Self::Tty(v) => v.select_last(),
             _ => {}
         }
     }
@@ -303,6 +354,7 @@ impl Preview {
             Self::Syntactic(sv) => sv.display(w, screen, panel_skin, area, con),
             Self::ZeroLen(zlv) => zlv.display(w, screen, panel_skin, area),
             Self::Hex(hv) => hv.display(w, screen, panel_skin, area),
+            Self::Tty(v) => v.display(w, screen, panel_skin, area),
             Self::IoError(err) => {
                 let mut y = area.top;
                 w.queue(cursor::MoveTo(area.left, y))?;
